@@ -1,13 +1,13 @@
 """This client pushes PCAPs -> MetaDaa -> ELS Indexer."""
 import zerorpc
 import os
-import workbench_client
+import client_helper
 
 def run():
     """This client pushes PCAPs -> MetaDaa -> ELS Indexer."""
     
     # Grab server args
-    args = workbench_client.grab_server_args()
+    args = client_helper.grab_server_args()
 
     # Start up workbench connection
     workbench = zerorpc.Client(timeout=300, heartbeat=60)
@@ -22,12 +22,13 @@ def run():
         if '.DS_Store' in filename: continue
 
         with open(filename,'rb') as pcap_file:
-            md5 = workbench.store_sample(filename, pcap_file.read(), 'pcap')
+            base_name = os.path.basename(filename)
+            md5 = workbench.store_sample(pcap_file.read(), base_name, 'pcap')
 
             # Index the view_pcap output (notice we can ask for any worker output)
             # Also (super important) it all happens on the server side.
             workbench.index_worker_output('view_pcap', md5, 'view_pcap', None)
-            print '\n\n<<< PCAP Data: %s Indexed>>>' % (filename)
+            print '\n\n<<< PCAP Data: %s Indexed>>>' % (base_name)
 
 def test():
     """Executes pcap_meta_indexer test."""
