@@ -18,9 +18,10 @@ import inspect
 import funcsigs
 import ConfigParser
 import magic
-from colorama import Fore as F, Style
 import datetime
 import lz4
+from IPython.utils.coloransi import TermColors as color
+#pylint: disable=no-member
 try:
     from cStringIO import StringIO
 except ImportError:
@@ -116,15 +117,7 @@ class WorkBench(object):
         # If the sample comes in with an unknown type_tag try to determine it
         if type_tag == 'unknown':
             print 'Info: Unknown File -- Trying to Determine Type...'
-            type_tag = self.guess_type_tag(input_bytes)
-            if type_tag == 'data':
-                print 'Info: File -- Trying to Determine Type from filename...'
-                ext = os.path.splitext(filename)[1][1:]
-                if ext in ['mem','vmem']:
-                    type_tag = 'mem'
-                else:
-                    print 'Alert: Failed to Determine Type for %s' % filename
-                    exit(1) # Temp
+            type_tag = self.guess_type_tag(input_bytes, filename)
 
         # Do we have a compressed sample? If so decompress it
         if type_tag == 'lz4':
@@ -275,7 +268,7 @@ class WorkBench(object):
             print 'Info: DataFrame compression %.0f%%' % (len(compress_df)*100.0/float(len(sample['raw_bytes'])))
             return compress_df
 
-    def guess_type_tag(self, input_bytes):
+    def guess_type_tag(self, input_bytes, filename):
         """ Try to guess the type_tag for this sample """
         mime_to_type = {'application/jar': 'jar',
                         'application/java-archive': 'jar',
@@ -287,6 +280,7 @@ class WorkBench(object):
                         'application/x-dosexec': 'exe',
                         'application/x-empty': 'empty',
                         'application/x-shockwave-flash': 'swf',
+                        'application/xml': 'xml',
                         'application/zip': 'zip',
                         'image/gif': 'gif',
                         'text/html': 'html',
@@ -300,7 +294,18 @@ class WorkBench(object):
         with magic.Magic(flags=magic.MAGIC_MIME_TYPE) as mag:
             mime_type = mag.id_buffer(input_bytes[:1024])
             if mime_type in mime_to_type:
-                return mime_to_type[mime_type]
+                type_tag = mime_to_type[mime_type]
+
+                # If we get 'data' back look at the filename
+                if type_tag == 'data':
+                    print 'Info: File -- Trying to Determine Type from filename...'
+                    ext = os.path.splitext(filename)[1][1:]
+                    if ext in ['mem','vmem']:
+                        type_tag = 'mem'
+                    else:
+                        print 'Alert: Failed to Determine Type for %s' % filename
+                        exit(1) # Temp
+                return type_tag
             else:
                 print 'Alert: Sample Type could not be Determined'
                 return 'unknown'
@@ -619,27 +624,27 @@ class WorkBench(object):
             # message that has both the md5 of what they were looking for and
             # a nice informative message that explains what might have happened
             sample_md5 = e.args[0]
-            return '%s%s\n\t%s%s%s' % (F.YELLOW, sample_md5, F.GREEN, e.message(), F.RESET)
+            return '%s%s\n\t%s%s%s' % (color.Yellow, sample_md5, color.Green, e.message(), color.Normal)
 
     # Fixme: These are internal methods that basically just provide help text
     def _help_workbench(self):
         """ Help on Workbench """
-        help = '%sWelcome to Workbench Help:%s' % (F.YELLOW, F.RESET)
-        help += '\n\t%s- workbench.help(\'basic\') %s for getting started help' % (F.GREEN, F.BLUE)
-        help += '\n\t%s- workbench.help(\'workers\') %s for help on available workers' % (F.GREEN, F.BLUE)
-        help += '\n\t%s- workbench.help(\'commands\') %s for help on workbench commands' % (F.GREEN, F.BLUE)
-        help += '\n\t%s- workbench.help(topic) %s where topic can be a help, command or worker' % (F.GREEN, F.BLUE)
-        help += '\n\n%sSee http://github.com/SuperCowPowers/workbench for more information\n%s' % (F.YELLOW, F.RESET)
+        help = '%sWelcome to Workbench Help:%s' % (color.Yellow, color.Normal)
+        help += '\n\t%s- workbench.help(\'basic\') %s for getting started help' % (color.Green, color.LightBlue)
+        help += '\n\t%s- workbench.help(\'workers\') %s for help on available workers' % (color.Green, color.LightBlue)
+        help += '\n\t%s- workbench.help(\'commands\') %s for help on workbench commands' % (color.Green, color.LightBlue)
+        help += '\n\t%s- workbench.help(topic) %s where topic can be a help, command or worker' % (color.Green, color.LightBlue)
+        help += '\n\n%sSee http://github.com/SuperCowPowers/workbench for more information\n%s' % (color.Yellow, color.Normal)
         return help
 
     def _help_basic(self):
         """ Help for Workbench Basics """
-        help =  '%sWorkbench: Getting started...' % (F.YELLOW)
-        help += '\n%sStore a sample into Workbench:'  % (F.GREEN)
-        help += '\n\t%s$ workbench.store_sample(raw_bytes, filename, type_tag)' % (F.BLUE)
-        help += '\n\n%sNotice store_sample returns an md5 of the sample...'% (F.YELLOW)
-        help += '\n%sRun workers on the sample (view, meta, whatever...):'  % (F.GREEN)
-        help += '\n\t%s$ workbench.work_request(\'view\', md5)%s' % (F.BLUE, F.RESET)
+        help =  '%sWorkbench: Getting started...' % (color.Yellow)
+        help += '\n%sStore a sample into Workbench:'  % (color.Green)
+        help += '\n\t%s$ workbench.store_sample(raw_bytes, filename, type_tag)' % (color.LightBlue)
+        help += '\n\n%sNotice store_sample returns an md5 of the sample...'% (color.Yellow)
+        help += '\n%sRun workers on the sample (view, meta, whatever...):'  % (color.Green)
+        help += '\n\t%s$ workbench.work_request(\'view\', md5)%s' % (color.LightBlue, color.Normal)
         return help
 
     def _help_commands(self):
