@@ -32,7 +32,7 @@ def test():
     import os
     data_path = os.path.join(os.path.dirname(os.path.realpath(__file__)),
                              '../data/pe/bad/505804ec7c7212a52ec85e075b91ed84')
-    md5 = workbench.store_sample('bad_pe', open(data_path, 'rb').read(), 'exe')
+    md5 = workbench.store_sample(open(data_path, 'rb').read(), 'bad_pe', 'exe')
     input_data = workbench.work_request('strings', md5)
 
     # Execute the worker (unit test)
